@@ -1,6 +1,4 @@
-( cd usr/include ; rm -rf ruby )
-( cd usr/include ; ln -sf ruby-1.9.1/arm-linux-eabi/ruby ruby )
-( cd usr/lib ; rm -rf libruby.so.1.9 )
-( cd usr/lib ; ln -sf libruby.so.1.9.1 libruby.so.1.9 )
 ( cd usr/lib ; rm -rf libruby.so )
 ( cd usr/lib ; ln -sf libruby.so.1.9.1 libruby.so )
+( cd usr/lib ; rm -rf libruby.so.1.9 )
+( cd usr/lib ; ln -sf libruby.so.1.9.1 libruby.so.1.9 )
